@@ -1,7 +1,7 @@
 """
 ## AWS Web Application Firewall Construct Library
 
-<html></html>---
+<!--BEGIN STABILITY BANNER-->---
 
 
 ![Stability: Experimental](https://img.shields.io/badge/stability-Experimental-important.svg?style=for-the-badge)
@@ -14,7 +14,7 @@
 > environments. Experimental APIs are not subject to the Semantic Versioning model.
 
 ---
-<html></html>
+<!--END STABILITY BANNER-->
 
 This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.
 """
@@ -30,7 +30,7 @@ import publication
 from jsii.python import classproperty
 
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.17.0", __name__, "aws-waf@1.17.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-waf", "1.17.1", __name__, "aws-waf@1.17.1.jsii.tgz")
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnByteMatchSet(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-waf.CfnByteMatchSet"):
     """A CloudFormation ``AWS::WAF::ByteMatchSet``.
